==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/zu-ZA/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Qinisekisa u-Bulk Susa amafa',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Buyekeza amafa wokususwa okuningi ngezansi. Uma usususiwe, la mafa angabuyiselwa, kodwa ngeke ahlanganiswe nanoma yimuphi abasebenzisi okwamanje abelwe wona.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Uzosusa: impahla ye-asethi_diza.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Ukuvuselela amafa we-Bulk',
    'bulk_update_help'	=> 'Leli fomu likuvumela ukuthi ubuyekeze amafa amaningi ngesikhathi esisodwa. Gcwalisa kuphela amasimu okudingayo ukuguqula. Noma yiziphi izinkambu ezishiywe zingenakushintshwa.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Ikhiyiwe Kuzo',
    'checkout_date'		=> 'Usuku lokuhlola',
    'checkin_date'		=> 'Usuku lokuhlola',
    'checkout_to'		=> 'I-Checkout iya',
    'cost'				=> 'Izindleko zokuthenga',
    'create'			=> 'Dala i-Asset',
    'date'				=> 'Usuku lokuthenga',
    'depreciation'	    => 'Ukunciphisa',
    'depreciates_on'	=> 'Iyancipha',
    'default_location'	=> 'Indawo okuzenzakalelayo',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Usuku lwe-EOL',
    'eol_rate'			=> 'I-EOL Rate',
    'expected_checkin'  => 'Ilanga le-Checkin elilindelekile',
    'expires'			=> 'Iphelelwa yisikhathi',
    'fully_depreciated'	=> 'Ukunciphisa ngokuphelele',
    'help_checkout'		=> 'Uma ufisa ukwabela le mali ngaso leso sikhathi, khetha "Ukulungele Ukusebenzisa" kusuka kuhlu lokulunga ngenhla.',
    'mac_address'		=> 'Ikheli le-MAC',
    'manufacturer'		=> 'Umkhiqizi',
    'model'				=> 'Isibonelo',
    'months'			=> 'izinyanga',
    'name'				=> 'Igama lefa',
    'notes'				=> 'Amanothi',
    'order'				=> 'Inombolo Ye-oda',
    'qr'				=> 'Ikhodi ye-QR',
    'requestable'		=> 'Abasebenzisi bangase bacele le mali',
    'select_statustype'	=> 'Khetha uhlobo lomumo',
    'serial'			=> 'Serial',
    'status'			=> 'Isimo',
    'tag'				=> 'Ithegi lefa',
    'update'			=> 'Ukuvuselelwa kwefa',
    'warranty'			=> 'Iwaranti',
        'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'iminyaka',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/zu-ZA/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Qinisekisa u-Bulk Susa amafa',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Buyekeza amafa wokususwa okuningi ngezansi. Uma usususiwe, la mafa angabuyiselwa, kodwa ngeke ahlanganiswe nanoma yimuphi abasebenzisi okwamanje abelwe wona.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Uzosusa: impahla ye-asethi_diza.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Ukuvuselela amafa we-Bulk',
    'bulk_update_help'	=> 'Leli fomu likuvumela ukuthi ubuyekeze amafa amaningi ngesikhathi esisodwa. Gcwalisa kuphela amasimu okudingayo ukuguqula. Noma yiziphi izinkambu ezishiywe zingenakushintshwa.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Ikhiyiwe Kuzo',
    'checkout_date'		=> 'Usuku lokuhlola',
    'checkin_date'		=> 'Usuku lokuhlola',
    'checkout_to'		=> 'I-Checkout iya',
    'cost'				=> 'Izindleko zokuthenga',
    'create'			=> 'Dala i-Asset',
    'date'				=> 'Usuku lokuthenga',
    'depreciation'	    => 'Ukunciphisa',
    'depreciates_on'	=> 'Iyancipha',
    'default_location'	=> 'Indawo okuzenzakalelayo',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Usuku lwe-EOL',
    'eol_rate'			=> 'I-EOL Rate',
    'expected_checkin'  => 'Ilanga le-Checkin elilindelekile',
    'expires'			=> 'Iphelelwa yisikhathi',
    'fully_depreciated'	=> 'Ukunciphisa ngokuphelele',
    'help_checkout'		=> 'Uma ufisa ukwabela le mali ngaso leso sikhathi, khetha "Ukulungele Ukusebenzisa" kusuka kuhlu lokulunga ngenhla.',
    'mac_address'		=> 'Ikheli le-MAC',
    'manufacturer'		=> 'Umkhiqizi',
    'model'				=> 'Isibonelo',
    'months'			=> 'izinyanga',
    'name'				=> 'Igama lefa',
    'notes'				=> 'Amanothi',
    'order'				=> 'Inombolo Ye-oda',
    'qr'				=> 'Ikhodi ye-QR',
    'requestable'		=> 'Abasebenzisi bangase bacele le mali',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Khetha uhlobo lomumo',
    'serial'			=> 'Serial',
    'status'			=> 'Isimo',
    'tag'				=> 'Ithegi lefa',
    'update'			=> 'Ukuvuselelwa kwefa',
    'warranty'			=> 'Iwaranti',
        'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'iminyaka',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];
